==> owncloud-app-calendar-1%3A1.3.2-3-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/da.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "Individuelt",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Lokale",
    "Unknown" : "Ukendt",
    "Required" : "Krævet",
    "Optional" : "Valgfri",
    "Does not attend" : "Deltager ikke",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du er i en ukendt tidszone ({tz}), -sætter tiden til UTC",
    "Please create a calendar first." : "Opret venligst en kalender først",
    "New event" : "Opret begivenhed",
    "Attendees" : "Deltagere",
    "Reminders" : "Påmindindelser",
    "Repeating" : "Gentagende",
    "When shared show full event" : "Når delt, vis den fulde begivenhed",
    "When shared show only busy" : "Når delt, vis kun optaget",
    "When shared hide this event" : "Når delt, skjul denne begivenhed",
    "Please add a title!" : "Vær venlig at tilføje en titel!",
    "Please select a calendar!" : "Vælg venligt kalender",
    "Global" : "Global",
    "None" : "Ingen",
    "Every day" : "Hver dag",
    "Every week" : "Hver uge",
    "Every month" : "Hver måmned",
    "Every year" : "Hvert år",
    "never" : "aldrig",
    "after" : "efter",
    "At time of event" : "På tidspunktet for begivenheden",
    "5 minutes before" : "5 minutter før",
    "10 minutes before" : "10 minutter før",
    "15 minutes before" : "15 minutter før",
    "30 minutes before" : "30 minutter før",
    "1 hour before" : "1 time før",
    "2 hours before" : "2 timer før",
    "Custom" : "Valgfrit",
    "Audio" : "Lyd",
    "E Mail" : "E-mail",
    "Pop up" : "Pop-up",
    "sec" : "sek",
    "min" : "min.",
    "hours" : "timer",
    "days" : "dage",
    "week" : "uge",
    "before" : "før",
    "start" : "start",
    "end" : "slut",
    "Editing reminders of unknown type not supported." : "Redigeringspåmindelser, af ukendt type, er ikke understøttet.",
    "Week {number} of {year}" : "Uge {number} i {year}",
    "Successfully imported" : "Importeret succesfuldt",
    "Partially imported, 1 failure" : "Delvist importeret, 1 fejl",
    "Partially imported, {n} failures" : "Delvist importeret, {n} fejl",
    "Audio alarm" : "Lyd alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} før begivenheden begynder",
    "{type} {time} before the event ends" : "{type} {time} før begivenheden slutter",
    "{type} {time} after the event starts" : "{type} {time} efter begivenheden begynder",
    "{type} {time} after the event ends" : "{type} {time} efter begivenheden slutter",
    "{type} at the event's start" : "{type} ved begivenhedens begyndelse",
    "{type} at the event's end" : "{type} ved begivenhedens slutning",
    "{type} at {time}" : "{type} på {time}",
    "{calendar} shared by {owner}" : "{calendar} delt af {owner}",
    "Title of the Event" : "Titel på begivenheden",
    "starts" : "starter",
    "ends" : "slutter",
    "All day Event" : "Heldagsbegivenhed",
    "Delete" : "Slet",
    "Cancel" : "Annullér",
    "More ..." : "Mere...",
    "Create" : "Ny",
    "Update" : "Opdatér",
    "Close" : "Luk",
    "Location" : "Placering",
    "Description" : "Beskrivelse",
    "Export" : "Eksportér",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund af en \"upstream bug\", er kalenderen, i øjeblikket, ikke i stand til at understøtte funktionen \"asset pipeline\".",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontakt venligst din administrator og bed om at \"asset-pipeline.enabled\" bliver slået fra.",
    "Day" : "Dag",
    "Week" : "Uge",
    "Month" : "Måned",
    "Today" : "I dag",
    "Share Calendar" : "Del kalender",
    "More" : "Mere",
    "Edit" : "Redigér",
    "CalDAV" : "CalDAV",
    "Share with users or groups" : "Del med brugere eller grupper",
    "can edit" : "kan redigere",
    "group" : "gruppe",
    "New Calendar" : "Ny kalender",
    "Subscriptions" : "Abonnementer",
    "New Subscription" : "Tilføj abonnement",
    "Url" : "Url",
    "Edit event" : "Rediger begivenhed",
    "Delete Event" : "Slet begivenhed",
    "Save Event" : "Gem begivenhed",
    "Time" : "Tid",
    "Type" : "Type",
    "Relative" : "Relative",
    "Absolute" : "Absolut",
    "Repeat" : "Gentag",
    "times every" : "gange hver",
    "Add" : "Tilføj",
    "E-Mail address of attendee" : "E-mailadresse på deltager",
    "Please add your email address in the personal settings in order to add attendees." : "Tilføj din e-mailadresse under Personlige indstillinger for at kunne invitere deltagere.",
    "from" : "fra",
    "to" : "til",
    "This event's repeating rule is not supported yet." : "Denne begivenheds gentagelsesregel understøttes ikke endnu.",
    "Support for advanced rules will be added with subsequent updates." : "Understøttelse af avancerede regler, vil blive tilføjet ved senere opdateringer.",
    "Reset repeating rule" : "Nulstil gentagelsesregel",
    "Repeat every ..." : "Gentag hver ...",
    "end repeat ..." : "stop gentagelse ...",
    "times" : "gange",
    "Import Calendars" : "Importer kalenderere",
    "Import canceled" : "Importering annulleret",
    "Analyzing calendar" : "Analyserer kalender",
    "The file contains objects incompatible with the selected calendar" : "Filen indeholder objekter som ikke er kompatible med den valgte kalender",
    "New calendar" : "Ny kalender",
    "Import scheduled" : "Importering planlagt",
    "Settings" : "Indstillinger",
    "Import calendar" : "Importer kalender",
    "No Calendars selected for import" : "Ingen kalendere er valgt til importering",
    "Primary CalDAV address" : "Primær CalDAV-adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-adresse"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-calendar-1%3A1.3.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/da.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "Individuelt",
    "Group" : "Gruppe",
    "Resource" : "Ressource",
    "Room" : "Lokale",
    "Unknown" : "Ukendt",
    "Required" : "Krævet",
    "Optional" : "Valgfri",
    "Does not attend" : "Deltager ikke",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du er i en ukendt tidszone ({tz}), -sætter tiden til UTC",
    "Please create a calendar first." : "Opret venligst en kalender først",
    "New event" : "Opret begivenhed",
    "Attendees" : "Deltagere",
    "Reminders" : "Påmindindelser",
    "Repeating" : "Gentagende",
    "When shared show full event" : "Når delt, vis den fulde begivenhed",
    "When shared show only busy" : "Når delt, vis kun optaget",
    "When shared hide this event" : "Når delt, skjul denne begivenhed",
    "Confirmed" : "Bekræftet",
    "Tentative" : "Foreløbig prøve",
    "Cancelled" : "Annulléret",
    "Please add a title!" : "Vær venlig at tilføje en titel!",
    "Please select a calendar!" : "Vælg venligt kalender",
    "Global" : "Global",
    "None" : "Ingen",
    "Every day" : "Hver dag",
    "Every week" : "Hver uge",
    "Every month" : "Hver måmned",
    "Every year" : "Hvert år",
    "never" : "aldrig",
    "after" : "efter",
    "At time of event" : "På tidspunktet for begivenheden",
    "5 minutes before" : "5 minutter før",
    "10 minutes before" : "10 minutter før",
    "15 minutes before" : "15 minutter før",
    "30 minutes before" : "30 minutter før",
    "1 hour before" : "1 time før",
    "2 hours before" : "2 timer før",
    "Custom" : "Valgfrit",
    "Audio" : "Lyd",
    "E Mail" : "E-mail",
    "Pop up" : "Pop-up",
    "sec" : "sek",
    "min" : "min.",
    "hours" : "timer",
    "days" : "dage",
    "week" : "uge",
    "before" : "før",
    "start" : "start",
    "end" : "slut",
    "Editing reminders of unknown type not supported." : "Redigeringspåmindelser, af ukendt type, er ikke understøttet.",
    "Week {number} of {year}" : "Uge {number} i {year}",
    "Successfully imported" : "Importeret succesfuldt",
    "Partially imported, 1 failure" : "Delvist importeret, 1 fejl",
    "Partially imported, {n} failures" : "Delvist importeret, {n} fejl",
    "Audio alarm" : "Lyd alarm",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} før begivenheden begynder",
    "{type} {time} before the event ends" : "{type} {time} før begivenheden slutter",
    "{type} {time} after the event starts" : "{type} {time} efter begivenheden begynder",
    "{type} {time} after the event ends" : "{type} {time} efter begivenheden slutter",
    "{type} at the event's start" : "{type} ved begivenhedens begyndelse",
    "{type} at the event's end" : "{type} ved begivenhedens slutning",
    "{type} at {time}" : "{type} på {time}",
    "{calendar} shared by {owner}" : "{calendar} delt af {owner}",
    "Title of the Event" : "Titel på begivenheden",
    "starts" : "starter",
    "ends" : "slutter",
    "All day Event" : "Heldagsbegivenhed",
    "Delete" : "Slet",
    "Cancel" : "Annullér",
    "More ..." : "Mere...",
    "Create" : "Ny",
    "Update" : "Opdatér",
    "Close" : "Luk",
    "Location" : "Placering",
    "Description" : "Beskrivelse",
    "Event status" : "Begivenhedens status",
    "Visibility when sharing" : "Synlighed ved deling",
    "Export" : "Eksportér",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund af en \"upstream bug\", er kalenderen, i øjeblikket, ikke i stand til at understøtte funktionen \"asset pipeline\".",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontakt venligst din administrator og bed om at \"asset-pipeline.enabled\" bliver slået fra.",
    "Day" : "Dag",
    "Week" : "Uge",
    "Month" : "Måned",
    "Today" : "I dag",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Nogle begivenheder i denne kalender er fejlbehæftet. Tjek venligst JS-konsollen for mere information.",
    "Share Calendar" : "Del kalender",
    "Shared" : "Delt",
    "More" : "Mere",
    "Edit" : "Redigér",
    "Link" : "Link",
    "Download" : "Hent",
    "Share with users or groups" : "Del med brugere eller grupper",
    "can edit" : "kan redigere",
    "group" : "gruppe",
    "New Calendar" : "Ny kalender",
    "Subscriptions" : "Abonnementer",
    "New Subscription" : "Tilføj abonnement",
    "Url" : "Url",
    "Edit event" : "Rediger begivenhed",
    "Delete Event" : "Slet begivenhed",
    "Save Event" : "Gem begivenhed",
    "Time" : "Tid",
    "Type" : "Type",
    "Relative" : "Relative",
    "Absolute" : "Absolut",
    "Repeat" : "Gentag",
    "times every" : "gange hver",
    "Add" : "Tilføj",
    "E-Mail address of attendee" : "E-mailadresse på deltager",
    "Please add your email address in the personal settings in order to add attendees." : "Tilføj din e-mailadresse under Personlige indstillinger for at kunne invitere deltagere.",
    "from" : "fra",
    "to" : "til",
    "This event's repeating rule is not supported yet." : "Denne begivenheds gentagelsesregel understøttes ikke endnu.",
    "Support for advanced rules will be added with subsequent updates." : "Understøttelse af avancerede regler, vil blive tilføjet ved senere opdateringer.",
    "Reset repeating rule" : "Nulstil gentagelsesregel",
    "Repeat every ..." : "Gentag hver ...",
    "end repeat ..." : "stop gentagelse ...",
    "times" : "gange",
    "Import Calendars" : "Importer kalenderere",
    "Import canceled" : "Importering annulleret",
    "Analyzing calendar" : "Analyserer kalender",
    "The file contains objects incompatible with the selected calendar" : "Filen indeholder objekter som ikke er kompatible med den valgte kalender",
    "New calendar" : "Ny kalender",
    "Import scheduled" : "Importering planlagt",
    "Settings" : "Indstillinger",
    "Skip simple event editor" : "Spring over enkel begivenheds tekstbehandler",
    "Import calendar" : "Importer kalender",
    "No Calendars selected for import" : "Ingen kalendere er valgt til importering",
    "Primary CalDAV address" : "Primær CalDAV-adresse",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-adresse"
},
"nplurals=2; plural=(n != 1);");
